Struct strategy_vaults::accounts::AddLiquidity
source · [−]pub struct AddLiquidity {Show 18 fields
pub vault: Pubkey,
pub user_account: Pubkey,
pub user_info_account: Pubkey,
pub token_a_funding_account: Pubkey,
pub token_b_funding_account: Pubkey,
pub lp_funding_account: Pubkey,
pub pool_coin_token_account: Pubkey,
pub pool_pc_token_account: Pubkey,
pub amm: Pubkey,
pub lp_mint: Pubkey,
pub amm_authority: Pubkey,
pub amm_target: Pubkey,
pub serum_market: Pubkey,
pub amm_open_orders: Pubkey,
pub pool_lp_custody_account: Pubkey,
pub pool_program: Pubkey,
pub spl_token_program: Pubkey,
pub clock_program: Pubkey,
}Expand description
Generated client accounts for AddLiquidity.
Fields
vault: Pubkeyuser_account: Pubkeyuser_info_account: Pubkeytoken_a_funding_account: Pubkeytoken_b_funding_account: Pubkeylp_funding_account: Pubkeypool_coin_token_account: Pubkeyalso known as token a
pool_pc_token_account: Pubkeyalso known as token b
amm: Pubkeylp_mint: PubkeyAMM Metadata
CHECK: Raydium will verify
amm_target: PubkeyCHECK: Raydium will verify
serum_market: PubkeyCHECK: Raydium will verify
amm_open_orders: PubkeyCHECK: Raydium will verify
pool_lp_custody_account: Pubkeypool_program: PubkeyCHECK: Raydium will verify
spl_token_program: Pubkeyclock_program: PubkeyTrait Implementations
sourceimpl BorshSerialize for AddLiquidity where
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
impl BorshSerialize for AddLiquidity where
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
sourceimpl ToAccountMetas for AddLiquidity
impl ToAccountMetas for AddLiquidity
sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
A: Allocator,
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client. Read more