Struct strategy_vaults::accounts::CreateVault
source · [−]pub struct CreateVault {Show 13 fields
pub vault: Pubkey,
pub base: Pubkey,
pub manager: Pubkey,
pub payer: Pubkey,
pub system_program: Pubkey,
pub vault_lp_token_mint: Pubkey,
pub farm_lp_mint: Pubkey,
pub farm_reward_token_a_mint: Pubkey,
pub farm_reward_token_b_mint: Pubkey,
pub pool_lp_custody_account: Pubkey,
pub pool_token_a_custody_account: Pubkey,
pub pool_token_b_custody_account: Pubkey,
pub amm: Pubkey,
}Expand description
Generated client accounts for CreateVault.
Fields
vault: PubkeyThis is a vault info account.
base: PubkeyBase of the Vault address.
manager: PubkeyManager of the vault.
payer: PubkeyFee payer.
system_program: PubkeySystem program.
vault_lp_token_mint: PubkeyVault Mint
farm_lp_mint: Pubkeyfarm_reward_token_a_mint: PubkeyReward Mints
farm_reward_token_b_mint: Pubkeypool_lp_custody_account: PubkeyThe Pool custody TokenAccounts.
pool_token_a_custody_account: Pubkeypool_token_b_custody_account: Pubkeyamm: PubkeyTrait Implementations
sourceimpl BorshSerialize for CreateVault where
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
impl BorshSerialize for CreateVault where
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
sourceimpl ToAccountMetas for CreateVault
impl ToAccountMetas for CreateVault
sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
A: Allocator,
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client. Read more