Struct strategy_vaults::accounts::CreateVaultThree
source · [−]pub struct CreateVaultThree {
pub vault: Pubkey,
pub base: Pubkey,
pub manager: Pubkey,
pub payer: Pubkey,
pub system_program: Pubkey,
pub stake_info_account: Pubkey,
pub stake_info_account_v5_mainnet: Pubkey,
pub stake_info_account_orca: Pubkey,
}Expand description
Generated client accounts for CreateVaultThree.
Fields
vault: PubkeyThis is a vault info account.
base: PubkeyBase of the Vault address.
manager: PubkeyManager of the vault.
payer: PubkeyFee payer.
system_program: PubkeySystem program.
stake_info_account: Pubkeystake_info_account_v5_mainnet: Pubkeystake_info_account_orca: PubkeyTrait Implementations
sourceimpl BorshSerialize for CreateVaultThree where
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
impl BorshSerialize for CreateVaultThree where
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
sourceimpl ToAccountMetas for CreateVaultThree
impl ToAccountMetas for CreateVaultThree
sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
A: Allocator,
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client. Read more